@@ -10,6 +10,13 @@
 # include "config.h"
 #endif
 
+#ifdef HAVE_SHL_LOAD	/* I love HPUX (jh) */
+# define dlopen  __forget_dlopen_4a_moment
+# define dlsym   __forget_dlsym_4a_moment
+# define dlclose __forget_dlclose_4a_moment
+# define dlerror __forget_dlerror_4a_moment
+#endif /* HAVE_SHL_LOAD */
+
 #ifndef USE_PTHREADS
 # undef HAVE_INET_NETA
 # undef HAVE_ADDR2ASCII
@@ -152,7 +159,21 @@
 #endif
 
 #ifdef HAVE_VALUES_H
+
+/*
+ * Most systems re-define MAXINT in values.h, so we avoid a naughty
+ * warning
+ */
+#ifdef MAXINT
+#define ___OLD_MAXINT MAXINT
+#undef MAXINT
+#endif
+
 #include <values.h>
+
+#ifndef MAXINT
+#define MAXINT ___OLD_MAXINT
+#endif
 #endif
 
 #ifdef HAVE_LIMITS_H
@@ -198,6 +219,10 @@
 #include <dl.h>
 #endif
 
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
+
 #ifdef BSD_BYTE_ORDERING
 # define FIX(n) (n)
 # define UNFIX(n) (n)
@@ -211,4 +236,11 @@
 #include <nessus/libnessus.h>
 #include <nessus-devel.h>
 
+#ifdef HAVE_SHL_LOAD	/* I love HPUX (jh) */
+# undef dlopen
+# undef dlsym
+# undef dlclose
+# undef dlerror
+#endif /* HAVE_SHL_LOAD */
+
 #endif /* not defined(___INCLUDES_H) */
