@@ -32,6 +32,14 @@ void comm_get_preferences_errors(struct arglist *);
 
 harglst * comm_get_sessions();
 int comm_server_restores_sessions(struct arglist *);
+int comm_server_detached_sessions(struct arglist *);
 void comm_delete_session(char*);
 void comm_restore_session(char*);
+void comm_stop_detached_session( char *name);
+
+#ifdef ENABLE_SAVE_TESTS
+harglst * comm_get_detached_sessions(void);
+#endif
+
+
 #endif
