@@ -19,6 +19,10 @@
 #ifndef _NESSUSC_FAMILIES_H
 #define _NESSUSC_FAMILIES_H
 
+#define ENABLE_FAMILY 1
+#define DISABLE_FAMILY 0
+#define ENABLE_FAMILY_BUT_DOS 2
+
 struct plugin_families {
 	char * name;
 	int enabled;
