@@ -23,6 +23,10 @@
 #endif /* _alloca */
 #endif /* _WIN32 */
 
+#ifdef HAVE_ALLOCA
+#define USE_ALLOCA
+#endif
+
 /* two dimensional interger/float array acess */
 #ifdef USE_ALLOCA
 # define I(x,y)    [(x) * num_points + (y)]
@@ -77,14 +81,14 @@ extern struct	GDC_FONT_T	GDC_fontc[];
 #define MOD_2PI(o)			( (o)>=(2.0*M_PI)? ((o)-(2.0*M_PI)): (((o)<0)? ((o)+(2.0*M_PI)): (o)) )
 #define MOD_360(o)			( (o)>=360? (o)-360: (o) )								/* assume !> 720 */ 
 
-struct tmp_slice_t { int	i;					// original index
-					 char	hidden;				// 'behind' top [3D] pie
-					 float	angle;				// radian 
-					 float	slice; };			// radian
-static float				pie_3D_rad;			// user requested 3D angle in radians
+struct tmp_slice_t { int	i;					/* original index*/
+					 char	hidden;				/* 'behind' top [3D] pie*/
+					 float	angle;				/* radian */
+					 float	slice; };			/* radian*/
+static float				pie_3D_rad;			/* user requested 3D angle in radians*/
 
-// degrees (radians) between angle a, and depth angle
-// 1&2, so comparisons can be done.
+/* degrees (radians) between angle a, and depth angle*/
+/* 1&2, so comparisons can be done.*/
 #define RAD_DIST1( a )		( (dist_foo1=ABS(((a>-.00001&&a<.00001)?0.00001:a)-pie_3D_rad)), ((dist_foo1>M_PI)? ABS(dist_foo1-2.0*M_PI): dist_foo1) )
 #define RAD_DIST2( a )		( (dist_foo2=ABS(((a>-.00001&&a<.00001)?0.00001:a)-pie_3D_rad)), ((dist_foo2>M_PI)? ABS(dist_foo2-2.0*M_PI): dist_foo2) )
 static float				dist_foo1, dist_foo2;
@@ -145,17 +149,17 @@ pie_gif( short			GIFWIDTH,
 				EdgeColor,
 				EdgeColorShd,
 #ifdef USE_ALLOCA
-				*SliceColor = alloca (num_points * sizeof (int)),
-				*SliceColorShd = alloca (num_points * sizeof (int));
+				*SliceColor = (int*)alloca (num_points * sizeof (int)),
+				*SliceColorShd = (int*)alloca (num_points * sizeof (int));
 #else
 				SliceColor[num_points],
 				SliceColorShd[num_points];
 #endif /* USE_ALLOCA */
-	float		rad = 0.0;					// radius
+	float		rad = 0.0;					/* radius*/
 	float		tot_val = 0.0;
 	float		pscl;
-	int			cx,							// affects PX()
-				cy;							// affects PY()
+	int			cx,							/* affects PX()*/
+				cy;							/* affects PY()*/
 								/* ~ 1% for a size of 100 pixs */
 								/* label sizes will more dictate this */
 	float		min_grphable = ( GDCPIE_other_threshold < 0?
@@ -165,26 +169,26 @@ pie_gif( short			GIFWIDTH,
 				num_slices2 = 0;
 	char		any_too_small = FALSE;
 #ifdef USE_ALLOCA
-	char		*others = alloca (num_points);
-	float		*slice_angle = alloca (3 * num_points * sizeof (float));
+	char		*others = (char*)alloca (num_points);
+	float		*slice_angle = (float*)alloca (3 * num_points * sizeof (float));
 #else
 	char		others[num_points];
-	float		slice_angle[3][num_points];	// must be used with others[]
+	float		slice_angle[3][num_points];	/* must be used with others[]*/
 #endif /* USE_ALLOCA */
 	char		threeD = ( type == GDC_3DPIE );
 
-	int			xdepth_3D      = 0,			// affects PX()
-				ydepth_3D      = 0;			// affects PY()
-	int			do3Dx = 0,					// reserved for macro use
+	int			xdepth_3D      = 0,			/* affects PX()*/
+				ydepth_3D      = 0;			/* affects PY()*/
+	int			do3Dx = 0,					/* reserved for macro use*/
 				do3Dy = 0;
 
-//	GDCPIE_3d_angle = MOD_360(90-GDCPIE_3d_angle+360);
+/*	GDCPIE_3d_angle = MOD_360(90-GDCPIE_3d_angle+360);*/
 	pie_3D_rad = TO_RAD( GDCPIE_3d_angle );
 
 	xdepth_3D      = threeD? (int)( cos((double)MOD_2PI(M_PI_2-pie_3D_rad+2.0*M_PI)) * GDCPIE_3d_depth ): 0;
 	ydepth_3D      = threeD? (int)( sin((double)MOD_2PI(M_PI_2-pie_3D_rad+2.0*M_PI)) * GDCPIE_3d_depth ): 0;
-//	xdepth_3D      = threeD? (int)( cos(pie_3D_rad) * GDCPIE_3d_depth ): 0;
-//	ydepth_3D      = threeD? (int)( sin(pie_3D_rad) * GDCPIE_3d_depth ): 0;
+/*	xdepth_3D      = threeD? (int)( cos(pie_3D_rad) * GDCPIE_3d_depth ): 0;*/
+/*	ydepth_3D      = threeD? (int)( sin(pie_3D_rad) * GDCPIE_3d_depth ): 0;*/
 
 	load_font_conversions();
 
@@ -206,8 +210,8 @@ pie_gif( short			GIFWIDTH,
 	int		cheight,
 			cwidth;
 
-	// maximum: no labels, explosions
-	// gotta start somewhere
+	/* maximum: no labels, explosions*/
+	/* gotta start somewhere*/
 	rad = (float)MIN( GIFWIDTH/2-(1+ABS(xdepth_3D)), GIFHEIGHT/2-(1+ABS(ydepth_3D))-title_hgt );
 
 	/* ok fix center, i.e., no floating re labels, explosion, etc. */
@@ -281,39 +285,39 @@ pie_gif( short			GIFWIDTH,
 
 				rad = MIN( rad, this_y_explode_limit );
 				rad = MIN( rad, this_x_explode_limit );
-
-				// ok at this radius (which is most likely larger than final)
-				// adjust for inter-label spacing
-//				if( lbl[i] && *lbl[i] )
-//					{
-//					char which_edge = slice_angle[0][i] > M_PI? +1: -1;		// which semi
-//					last_label_yedge = cheight - (int)( (rad +				// top or bottom of label
-//														(float)(this_explode +
-//														(float)GDCPIE_label_dist)) * (float)this_cos ) +
-//											     ( (GDC_fontc[GDCPIE_label_size].h+1)/2 +
-//													GDC_label_spacing )*which_edge;
-//					}
-
+#if 0
+				/* ok at this radius (which is most likely larger than final)*/
+				/* adjust for inter-label spacing*/
+/*				if( lbl[i] && *lbl[i] )*/
+/*					{*/
+//					char which_edge = slice_angle[0][i] > M_PI? +1: -1;		/* which semi*/
+//					last_label_yedge = cheight - (int)( (rad +				/* top or bottom of label*/
+/*														(float)(this_explode +*/
+/*														(float)GDCPIE_label_dist)) * (float)this_cos ) +*/
+/*											     ( (GDC_fontc[GDCPIE_label_size].h+1)/2 +*/
+/*													GDC_label_spacing )*which_edge;*/
+/*					}*/
+#endif
 				/* radius constriant due to exploded depth */
 				/* at each edge of the slice, and the middle */
 				/* this is really stupid */
 				/*  this section uses a different algorithm then above, but does the same thing */
 				/*  could be combined, but each is ugly enough! */
-// PROTECT /0
+/* PROTECT /0*/
 				if( threeD )
 					{
 					short	j;
 					int		this_y_explode_pos;
 					int		this_x_explode_pos;
 
-					// first N E S W (actually no need for N)
-					if( (slice_angle I(1,i) < M_PI_2 && M_PI_2 < slice_angle I(2,i)) &&				// E
+					/* first N E S W (actually no need for N)*/
+					if( (slice_angle I(1,i) < M_PI_2 && M_PI_2 < slice_angle I(2,i)) &&				/* E*/
 						(this_x_explode_pos=OX(i,M_PI_2,1)) > cx+cwidth )
 						rad -= (float)ABS( (double)(1+this_x_explode_pos-(cx+cwidth))/sin(M_PI_2) );
-					if( (slice_angle I(1,i) < 3.0*M_PI_2 && 3.0*M_PI_2 < slice_angle I(2,i)) &&		// W
+					if( (slice_angle I(1,i) < 3.0*M_PI_2 && 3.0*M_PI_2 < slice_angle I(2,i)) &&		/* W*/
 						(this_x_explode_pos=OX(i,3.0*M_PI_2,1)) < cx-cwidth )
 						rad -= (float)ABS( (double)(this_x_explode_pos-(cx+cwidth))/sin(3.0*M_PI_2) );
-					if( (slice_angle I(1,i) < M_PI && M_PI < slice_angle I(2,i)) &&					// S
+					if( (slice_angle I(1,i) < M_PI && M_PI < slice_angle I(2,i)) &&					/* S*/
 						(this_y_explode_pos=OY(i,M_PI,1)) > cy+cheight )
 						rad -= (float)ABS( (double)(1+this_y_explode_pos-(cy+cheight))/cos(M_PI) );
 
@@ -382,8 +386,8 @@ pie_gif( short			GIFWIDTH,
 	/*              determined by number of labels that'll fit (height) */
 	/* scale to user values */
 	/* ( M_PI / (GIFHEIGHT / (SFONTHGT+1)) ) */
-//	min_grphable = tot_val /
-//				   ( 2.0 * (float)GIFHEIGHT / (float)(SFONTHGT+1+TFONTHGT+2) );
+/*	min_grphable = tot_val /*/
+/*				   ( 2.0 * (float)GIFHEIGHT / (float)(SFONTHGT+1+TFONTHGT+2) );*/
 
 
 	if( threeD )
@@ -425,7 +429,7 @@ pie_gif( short			GIFWIDTH,
 		{
 		struct tmp_slice_t	
 #ifdef USE_ALLOCA
-							*tmp_slice = alloca ((2*num_points+2) * sizeof (struct tmp_slice_t));
+							*tmp_slice = (struct tmp_slice_t*)alloca ((2*num_points+2) * sizeof (struct tmp_slice_t));
 #else
 							tmp_slice[2*num_points+2];
 #endif
@@ -449,7 +453,7 @@ pie_gif( short			GIFWIDTH,
 				tmp_slice[num_slice_angles].i       = i;
 				tmp_slice[num_slice_angles].slice   = slice_angle I(0,i);
 				tmp_slice[num_slice_angles++].angle = slice_angle I(2,i);
-				// identify which 2 slices (i) have a tangent parallel to depth angle 
+				/* identify which 2 slices (i) have a tangent parallel to depth angle */
 				if( slice_angle I(1,i)<MOD_2PI(pie_3D_rad+M_PI_2) && slice_angle I(2,i)>MOD_2PI(pie_3D_rad+M_PI_2) )
 					{
 					tmp_slice[num_slice_angles].i       = i;
@@ -510,7 +514,7 @@ pie_gif( short			GIFWIDTH,
 
 	/* ----- pie face ----- */
 	{
-	// float	last = 0.0;
+	/* float	last = 0.0;*/
 	  float	_rad1 = rad; /* _WIN32 does not like rad1, using _rad1, instead (jordan) */
 	for( i=0; i<num_points; ++i )
 		if( !others[i] &&
@@ -518,8 +522,8 @@ pie_gif( short			GIFWIDTH,
 			{
 			float	rad = _rad1;
 
-			// last += val[i];
-			// EXPLODE_CX_CY( slice_angle[0][i], i );
+			/* last += val[i];*/
+			/* EXPLODE_CX_CY( slice_angle[0][i], i );*/
 			gdImageLine( im, CX(i,0), CY(i,0), IX(i,1,0), IY(i,1,0), SliceColor[i] );
 			gdImageLine( im, CX(i,0), CY(i,0), IX(i,2,0), IY(i,2,0), SliceColor[i] );
 
@@ -634,7 +638,7 @@ pie_gif( short			GIFWIDTH,
 								   slice_angle I(0,i) <= M_PI? pctx:
 															  pctx+lbl_wdth-pct_wdth,
 								   pcty,
-								   pct_str,
+								   (u_char*)pct_str,
 								   LineColor );
 				if( lbl[i] )
 					GDCImageStringNL( im,
@@ -661,7 +665,7 @@ pie_gif( short			GIFWIDTH,
 	return;
 }
 
-/* $Id: gdc_pie.c,v 1.5 2000/05/28 10:21:05 jordan Exp $
+/* $Id: gdc_pie.c,v 1.6 2000/10/29 00:21:59 renaud Exp $
  * local variables:
  * mode: c
  * tab-width: 4
