@@ -335,7 +335,7 @@ void latex_print_host_ports_problems(FILE * f, struct arglist * port)
     {
     char * c = holes->value;
     while(c[0]=='\n')c++;
-    fprintf(f, "\\item \\begin{verbatim}\n");
+    fprintf(f, "\\item \\begin{verbatim}");
     printf_formatted_text(f, c, 70, NULL);
     fprintf(f, "\n\\end{verbatim}");
     holes = holes->next;
@@ -350,7 +350,7 @@ void latex_print_host_ports_problems(FILE * f, struct arglist * port)
     {
      char * c = info->value;
      while(c[0]=='\n')c++;
-     fprintf(f, "\\item \\begin{verbatim}\n");
+     fprintf(f, "\\item \\begin{verbatim}");
      printf_formatted_text(f, c, 70, NULL);
      fprintf(f, "\n\\end{verbatim}");
      info = info->next;
@@ -365,7 +365,7 @@ void latex_print_host_ports_problems(FILE * f, struct arglist * port)
     {
      char * c = note->value;
      while(c[0]=='\n')c++;
-     fprintf(f, "\\item \\begin{verbatim}\n");
+     fprintf(f, "\\item \\begin{verbatim}");
      printf_formatted_text(f, c, 70, NULL);
      fprintf(f, "\n\\end{verbatim}");
      note = note->next;
