@@ -19,6 +19,6 @@
 #ifndef _NESSUSC_MONITOR_DIALOG_H
 #define _NESSUSC_MONITOR_DIALOG_H
 
-void monitor_dialog_setup(char *);
+void monitor_dialog_setup(char *, int);
 void monitor_remove_host(char *);
 #endif
