@@ -55,6 +55,9 @@
 #include "cli.h"
 
 
+#ifdef ENABLE_SAVE_TESTS
+#include "detached_index.h"
+#endif
 
 
 struct arglist * Plugins = NULL;
@@ -62,6 +65,7 @@ struct arglist * Scanners = NULL;
 #ifdef ENABLE_SAVE_TESTS
 harglst * Sessions = NULL;
 int Sessions_saved = 0;
+int Detached_sessions_saved = 0;
 #endif
 #ifdef ENABLE_SAVE_KB
 int DetachedMode = 0;
@@ -101,6 +105,9 @@ peks_key   *key = 0;
 /* key file processing options ... */
 static int chng_pph = 0, list_kdb = 0;
 static char *kill_key = 0 ;
+static char *key_expfile = 0 ;
+static int exit_after_keygen = 0 ;
+static int suppr_path_check = 0 ;
 
 #ifdef USE_GTK
 /* choose gui authentication dialogue by default */
@@ -124,14 +131,72 @@ action_header
 #define action_header(s) /* nothing */
 #endif
 
+#ifdef _WIN32
+# define get_private_key(a,b,c,d) peks_private_key (a,b,c,d)
+
+#else
+static peks_key *
+get_private_key  
+  (const char *usrathost,
+   const char *file, 
+   char *(*get_pwd)(int),
+   unsigned  keylen)
+{
+  peks_key *k ;
+  int prterr ;
+
+  if ((k = peks_private_key (usrathost, file, get_pwd, keylen)) != 0 ||
+      suppr_path_check == 0)
+    return k ;
+ 
+  /* so k != 0 && path check is not suppressed */
+  prterr = errno ;
+
+  peks_admin_equiv (-1,-1); /* retry without path check */
+  if ((k = peks_private_key (usrathost, file, get_pwd, keylen)) == 0 ||
+      getenv ("NESSUSHOME") == 0 ||
+      getenv ("NESSUSUSER") != 0 && getuid() == 0) /* root ? */
+    return k ;
+
+  /* so k != 0 && $NESSUSHOME != 0 */
+
+# define _BLURB "WARNING: %s.\n" \
+	        "     ... retrying without path check " \
+	        "as requested!\n\n"
+
+# ifdef USE_GTK
+  if (F_quiet_mode)
+# endif    
+    fprintf (stderr, _BLURB, peks_strerr (prterr));
+# ifdef USE_GTK
+  else {
+    char * error = emalloc(50 + strlen(peks_strerr(prterr)) + sizeof (_BLURB));
+    sprintf(error, _BLURB, peks_strerr(prterr));
+    show_warning (error);
+    free(error);
+  }
+# endif
+# undef _BLURB
+
+  return k;
+}
+#endif /* not _WIN32 */
+
 static void
 key_initialization_stuff 
   (void)
 {
   int did_something = 0 ;
 
+# if 1 /* XXXXXXXXXXXXXXXXXX */
+  /* do not check directory paths for versions == 1.0.7 */
+    peks_admin_equiv (-1,-1);
+# endif
+
   if (chng_pph) { /* change pass phrase and exit */
-    if ((key = peks_private_key (0, kf, peks_get_pwd, keylen)) == 0) goto error ;
+    if ((key = get_private_key (0, kf, peks_get_pwd, keylen)) == 0) {
+      goto error ;
+    }
     ntconsole (10, 80, 0, 0);
     action_header ("Change pass phrase");
     if (!created_private_key () &&
@@ -149,33 +214,70 @@ key_initialization_stuff
 
   if (list_kdb) { /* list key data base */
     if (key == 0 &&
-        (key = peks_private_key (0, kf, peks_get_pwd, keylen)) == 0) goto error ;
+        (key = get_private_key (0, kf, peks_get_pwd, keylen)) == 0) {
+      goto error ;
+    }
     ntconsole (40, 80, 10, 70);
     action_header ("Key data base");
     if (peks_list_keyfile (0, kf) < 0) goto error ;
     did_something ++ ;
   }
+
+  if (key_expfile != 0) {
+    const char *usr = peks_get_username ();
+#   define __TMPL "%s@127.0.0.1" 
+    char *buf ;
+    int n ;
+    if (key == 0 &&
+        (key = get_private_key (0, kf, peks_get_pwd, keylen)) == 0) {
+      goto error ;
+    }
+    sprintf (buf = malloc (strlen (usr) + sizeof (__TMPL)), 
+	     __TMPL, usr ? usr : "nobody");
+    n = peks_save_public_key (buf, key, key_expfile);
+    free (buf);
+    if (n < 0) goto error;
+    did_something ++ ;
+#   undef __TMPL
+  }
 	
+  if (exit_after_keygen) {
+    if (key == 0 && get_private_key (0, kf, peks_get_pwd, keylen) == 0)
+      goto error ;
+    did_something ++ ;
+  }
+
   if (did_something)
     exit (0);
 
   /* get your private key */
-  if (key != 0 || (key = peks_private_key (0, kf, peks_get_pwd, keylen)) != 0)
+  if (key != 0 || (key = get_private_key (0, kf, peks_get_pwd, keylen)) != 0)
     return ;
 
   error:
+# define _BLURB  "\n *** If this is unavoidable, you may try " \
+                 "restarting with the " \
+		 "--suppress-cfg-check option !!\n\n"
 # ifdef USE_GTK
   if(F_quiet_mode)
 # endif    
-    fprintf (stderr, "%s - aborting.\n", peks_strerr (errno));
+    {
+      fprintf (stderr, "%s - aborting.\n", peks_strerr (errno));
+      if (key == 0 && suppr_path_check == 0)
+	fprintf (stderr, _BLURB);
+    }
 # ifdef USE_GTK
   else {
-    char * error = emalloc(40 + strlen(peks_strerr(errno)));
-    sprintf(error, "%s - aborting.", peks_strerr(errno));
+    char * error = emalloc(50 + strlen(peks_strerr(errno)) + sizeof (_BLURB));
+    if (key == 0 && suppr_path_check == 0)
+      sprintf(error, "%s - aborting." _BLURB, peks_strerr(errno));
+    else
+      sprintf(error, "%s - aborting.", peks_strerr(errno));
     show_error_and_wait(error);
     free(error);
   } 
 # endif    
+# undef _BLURB
   exit (1);
 }
 #endif
@@ -201,7 +303,7 @@ connect_to_nessusd(hostname, port, login, pass)
 	char * pass; /* is a cipher in case of the crypto layer */
 {
   int soc;
-  
+  int opt;
 #ifndef USE_AF_INET
   struct sockaddr_un address;
   char * name = AF_UNIX_PATH;
@@ -229,7 +331,11 @@ connect_to_nessusd(hostname, port, login, pass)
   	else
   	return("Could not open a connection to the remote host");
   	}
- 
+ opt = 1;
+ if(setsockopt(soc, SOL_SOCKET, SO_KEEPALIVE, &opt, sizeof(opt)) < 0)
+ {
+  return(strerror(errno));
+ }
 #else
   if((soc = socket(AF_UNIX, SOCK_STREAM,0))==-1){
   	perror("socket ");
@@ -252,7 +358,7 @@ connect_to_nessusd(hostname, port, login, pass)
 
     /* we explicitely require the cipher protocol */
     if(comm_init (soc, CIPHER_PROTO_NAME))
-      return "Remote host is not using " /* string concat */ CIPHER_PROTO_NAME;
+      return "Remote host is not using " /* string concat */ CIPHER_PROTO_NAME " or is tcpwrapped";
 
     if (client_negotiate_session_key (pass, soc, hostname, NESSUS_KEYFILE) < 0)
       return peks_strerr(errno); /* < 0: error, or just a new server key */
@@ -294,7 +400,7 @@ connect_to_nessusd(hostname, port, login, pass)
 	wrong_protocol:
 #endif	
         shutdown(soc, 2);
-  	return("Remote host is not using the good version of the Nessus communication protocol (1.2)");
+  	return("Remote host is not using the good version of the Nessus communication protocol (1.2) or is tcpwrapped");
         }
   if(comm_get_pluginlist())return("Login failed");
   if(!First_time){
@@ -324,6 +430,14 @@ connect_to_nessusd(hostname, port, login, pass)
  
   	
   prefs_check_defaults(Prefs);
+#ifdef ENABLE_SAVE_TESTS
+#ifdef USE_GTK
+  if(comm_server_detached_sessions(Prefs))
+    detached_show_window(Prefs);
+#endif  
+#endif
+
+  
 #ifdef USE_GTK
   prefs_plugins_reset(arg_get_value(MainDialog, "PLUGINS_PREFS"), Plugins,
    			Scanners);
@@ -371,22 +485,28 @@ display_help
 #ifdef ENABLE_CRYPTO_LAYER /* => USE_AF_INET */
   ntconsole (40, 100, 30, 80);
  printf ("\n\
-Usage: %s [options] "
+Usage: %s [options] ", pname);
 #ifdef USE_GTK
-	 "["
+ printf("[");
 #endif
-	 "SERVER PORT LOGIN TRG RESULT"
+ printf("SERVER PORT LOGIN TRG RESULT");
 #ifdef USE_GTK
-	 "]"
+ printf("]");
 #endif
-	 "\n", pname);  printf ("\n\
+printf("\n");  printf ("\n\
 Options:\n\
   -v, --version                       display version number and exit\n");
 #ifdef USE_GTK
 printf ("\
   -n, --no-pixmaps                    does not display any pixmaps\n\
-  -r, --open-report                   open-report file in the gui\n\
+  -r, --open-report                   open-report file in the gui\n");
+#endif
+printf ("\
   -c, --config-file                   use another configuration file\n");
+#ifndef _WIN32
+printf ("\
+  -S, --suppress-cfg-check            ignore improperly set up access\n\
+                                      rights of path segments\n");
 #endif
 printf ("\
   -h, --help                          show this help text\n\
@@ -394,48 +514,46 @@ printf ("\
 	NESSUS_SIGKEYLEN); printf ("\
   -C, --change-pass-phrase            interactively change the pass phrase\n\
                                       for the private key\n\
+  -G, --gen-key	                      generate key if missing, then exit\n\
   -L, --list-keys                     list all keys in the data base\n\
   -K KEY, --delete-key=KEY            delete a particular key from the\n\
                                       key data base\n\
+  -X FILE, --export-pubkey=FILE       append the public key to FILE, unless\n\
+                                      present in the FILE\n\
   -T type, --output-type=type	      Select output type for quiet mode\n\
-                                      (text, html, tex or nsr)\n"
+                                      (text, html, tex or nsr)\n");
 #ifdef ENABLE_SAVE_TESTS				      
-"\
+printf("\
   -s, --list-sessions		      List the sessions available on the remote\n\
                                       host (must be used with -q)\n\
-  -R ID, --restore-session=ID	      Restore  the session <ID>\n"			      
+  -R ID, --restore-session=ID	      Restore  the session <ID>\n");		      
 #endif  	      
-"\
-  -q, --batch-mode                    "
+printf("\
+  -m, --make-config-file	      Generates a config file (must be used w/ -q)\n-q, --batch-mode                    ");
 #ifdef USE_GTK
-                                     "force an error if there is no\n\
-                                      argument list, given"
+ printf("force an error if there is no\nargument list, given");
 #else
-                                     "ignored (compatibiltity mode, only)"
+ printf("ignored (compatibiltity mode, only)");
 #endif
-"\n\
-Argument list:\n"
+ printf("\nArgument list:\n");
 #ifdef ENABLE_SAVE_TESTS
-"\
-  SERVER PORT LOGIN [TRG] [RESULT]\n"
+ printf("SERVER PORT LOGIN [TRG] [RESULT]\n");
 #else
-"\
-  SERVER PORT LOGIN TRG RESULT\n"
+ printf("SERVER PORT LOGIN TRG RESULT \n");
 #endif
-"\
+printf("\
     |     |    |     |   |\n\
     |     |    |     |   +-- file name where nessus stores the results, in\n\
     |     |    |     +------ file name containing the target host adresses\n\
     |     |    +------------ the nessusd login name\n\
     |     +----------------- the port, nessusd listens on\n\
-    +----------------------- the host address, nessusd runs on\n\
-\n"
+    +----------------------- the host address, nessusd runs on\n\n");
 #ifdef USE_GTK
-"\
+printf("\
   If an argument list is given, all tests are run silently without gui\n\
-  support.  "
+  support.  ");
 #endif
-  "Results are printed when the tests are done.\n");
+ printf("Results are printed when the tests are done.\n");
 
 #else /* standard version */
  printf("%s, version %s\n", pname, NESSUS_VERSION);
@@ -521,6 +639,7 @@ int main(int argc, char * argv[])
   char *myself, **xav;
   int gui = 1;
   output_func_t output_func = NULL;
+  int opt_m = 0;
 #ifdef ENABLE_SAVE_TESTS  
   int list_sessions = 0;
   int restore_session = 0;
@@ -529,6 +648,7 @@ int main(int argc, char * argv[])
   /*
    * Version check
    */
+
   if(version_check(NESSUS_VERSION, nessuslib_version())>0)
   {
    fprintf(stderr, 
@@ -538,6 +658,7 @@ you have deleted older versions nessus libraries from your system\n",
         nessuslib_version(), NESSUS_VERSION);
    exit (1);
   }
+
   
 #ifdef ENABLE_CRYPTO_LAYER  
   /*
@@ -573,8 +694,9 @@ you have deleted older versions of libpeks from your system\n",
 #endif
 
 #ifdef ENABLE_CRYPTO_LAYER
-  /* allow to ue another name for HOME */
+  /* allow to use another name for HOME, LOGNAME */
   peks_set_homevar ("NESSUSHOME");
+  peks_set_uservar ("NESSUSUSER");
 #endif
 
   /* provide a extra acrgc/argv vector for later use */
@@ -588,8 +710,10 @@ you have deleted older versions of libpeks from your system\n",
     {
       {"help",                 no_argument, 0, 'h'},
       {"version",              no_argument, 0, 'v'},
+      {"gen-key",              no_argument, 0, 'G'},   
       {"delete-key",     required_argument, 0, 'K'},
       {"list-keys",            no_argument, 0, 'L'},
+      {"export-pubkey",  required_argument, 0, 'X'},
       {"change-pass-phrase",   no_argument, 0, 'C'},
       {"set-key-length", required_argument, 0, 'k'},   
 #ifdef USE_GTK
@@ -597,17 +721,19 @@ you have deleted older versions of libpeks from your system\n",
       {"no-pixmap",            no_argument, 0, 'n'},
 #endif
       {"batch-mode",           no_argument, 0, 'q'},
-      {"config-file",		required_argument, 0, 'c'},
-      {"output-type",			required_argument, 0, 'T'},
+      {"make-config-file",     no_argument, 0, 'm'},
+      {"config-file", 	 required_argument, 0, 'c'},
+      {"suppress-cfg-check",   no_argument, 0, 'S'}, 
+      {"output-type",	 required_argument, 0, 'T'},
 #ifdef ENABLE_SAVE_TESTS      
-      {"list-sessions",		no_argument, 0, 's'},
-      {"restore-session",       required_argument, 0, 'R'},
+      {"list-sessions",        no_argument, 0, 's'},
+      {"restore-session",required_argument, 0, 'R'},
 #endif      
       {0, 0, 0, 0}
     };
 
     if ((i = getopt_long 
-	 (argc, argv, "c:T:vhqnk:?CLK:r:01sR:", long_options, &option_index)) == EOF)
+	 (argc, argv, "c:T:X:vhqnk:?GCLK:r:01sR:Sm", long_options, &option_index)) == EOF)
       break;
      else
       
@@ -621,13 +747,14 @@ you have deleted older versions of libpeks from your system\n",
         if(optarg[0]=='=')inc_optind(); /* no optind++ on Win32 -- jordan */
 	if(!strcmp(optarg, "text"))output_func = arglist_to_text;
 	else if(!strcmp(optarg, "html"))output_func = arglist_to_html;
+	else if(!strcmp(optarg, "html_graph"))output_func = arglist_to_html_graph;
 	else if(!strcmp(optarg, "tex"))output_func = arglist_to_latex;
 	else if(!strcmp(optarg, "latex"))output_func = arglist_to_latex;
 	else if(!strcmp(optarg, "nsr"))output_func = arglist_to_file;
 	else if(!strcmp(optarg, "xml"))output_func = arglist_to_xml;
 	else {
 		fprintf(stderr, "%s - invalid output type\n", optarg);
-		fprintf(stderr, "Valid types are : text, html, tex, xml and nsr\n");
+		fprintf(stderr, "Valid types are : text, html, html_graph, tex, xml and nsr\n");
 		exit (1);
 	     }
 	break;    
@@ -670,6 +797,12 @@ you have deleted older versions of libpeks from your system\n",
      break;
 #endif
 
+#  ifndef _WIN32
+   case 'S' :
+     suppr_path_check = 1 ;
+     break;
+#  endif
+
    case 'K' :
      gui = 0;
      kill_key = estrdup (optarg) ;
@@ -680,6 +813,11 @@ you have deleted older versions of libpeks from your system\n",
      list_kdb++;
      break;
 
+   case 'X' :
+     gui = 0;
+     key_expfile = estrdup (optarg) ;
+     break;
+
    case 'C' :
      gui = 0;
      chng_pph++;
@@ -692,8 +830,14 @@ you have deleted older versions of libpeks from your system\n",
      fprintf (stderr, "%s : Key lengths smaller than %u are unsupported!\n", 
 	      myself, NESSUS_MINKEYLEN);
      exit (1) ;
-#endif /* ENABLE_CRYPTO_LAYER */
 
+   case 'G' :
+     exit_after_keygen = 1 ;
+     break;
+#endif /* ENABLE_CRYPTO_LAYER */
+    case 'm' :
+      opt_m ++;
+      break;
     case 'q' :
       gui = 0; 
       F_quiet_mode ++ ;
@@ -719,6 +863,12 @@ you have deleted older versions of libpeks from your system\n",
 
  if(!gui)F_quiet_mode = 1;
  
+ if(opt_m && !F_quiet_mode)
+ {
+  display_help(myself);
+  exit(1);
+ }
+	
 #ifdef ENABLE_SAVE_TESTS
  if(list_sessions && (argc<=optind) && !F_quiet_mode)
  {
@@ -766,9 +916,14 @@ you have deleted older versions of libpeks from your system\n",
 #endif
   
   /* system environment set up */
+  if(!opt_m)
+  {
   if (preferences_init(&Prefs))
     exit (2);
-
+ }
+ else
+  Prefs = emalloc(sizeof(struct arglist));
+  
 #ifdef ENABLE_CRYPTO_LAYER      
   key_initialization_stuff ();
 #endif
@@ -802,11 +957,14 @@ you have deleted older versions of libpeks from your system\n",
 
 #ifndef ENABLE_SAVE_TESTS
     if (argc - optind != NUM_ARGS) {
-      display_help(myself);
-      exit(0);
+      if(!((argc - optind == NUM_ARGS - 2) && opt_m))
+      {
+       display_help(myself);
+       exit(0);
+       }
     }
 #else
- if(list_sessions)
+ if(list_sessions || opt_m)
   {
   if (argc - optind != NUM_ARGS - 2) {
       display_help(myself);
@@ -848,9 +1006,14 @@ you have deleted older versions of libpeks from your system\n",
 #endif	
 
 #ifndef ENABLE_SAVE_TESTS
-    cli_args_target(cli, argv[inc_optind()]);
-    cli_args_results(cli,  argv[inc_optind()]);
+    if(!opt_m)
+    {
+     cli_args_target(cli, argv[inc_optind()]);
+     cli_args_results(cli,  argv[inc_optind()]);
+    }
 #else  
+   if(!opt_m)
+   {
    if(restore_session)
    {
      cli_args_results(cli,  argv[inc_optind()]);
@@ -861,7 +1024,7 @@ you have deleted older versions of libpeks from your system\n",
      cli_args_target(cli, argv[inc_optind()]);
      cli_args_results(cli,  argv[inc_optind()]);
      }
-   
+   }
    
 #endif      
 
@@ -876,7 +1039,7 @@ you have deleted older versions of libpeks from your system\n",
     if(list_sessions){
     	cli_list_sessions(cli);
 	shutdown(GlobalSocket,2);
-	close(GlobalSocket);
+	closesocket(GlobalSocket);
 	GlobalSocket = -1;
 	exit(0);
 	}
@@ -885,8 +1048,15 @@ you have deleted older versions of libpeks from your system\n",
 	}
    else	
 #endif    	
-    cli_test_network(cli);
-    cli_report(cli);
+    if(opt_m){
+    	if(!preferences_generate_new_file())
+	 printf("A new nessusrc file has been saved\n");
+	}
+    else
+     {
+     cli_test_network(cli);
+     cli_report(cli);
+    }
     /* end, exit */
     exit(0);
   }
@@ -898,7 +1068,6 @@ you have deleted older versions of libpeks from your system\n",
    */
 
 #ifdef USE_GTK
-  
   prefs_dialog_setup (NULL, Prefs);
  
   /*
