@@ -19,6 +19,14 @@
 #ifndef _NESSUSC_NESSUS_H
 #define _NESSUSC_NESSUS_H
 
+/* The default port assigned to nessus by the iana is 1241, see
+   http://www.isi.edu/in-notes/iana/assignments/port-numbers */
+#ifdef _WIN32
+#ifndef NESIANA_PORT
+#define NESIANA_PORT 1241
+#endif
+#endif
+
 #define DEFAULT_SERVER "localhost"
 #define PROTO_NAME "< NTP/1.2 >\n"
 
@@ -26,8 +34,13 @@
 #define DEFAULT_CIPHER    "twofish/ripemd160:3" /* alternatively: "none" */
 #define CIPHER_PROTO_NAME "< NSP/0.3 >\n"
 #define NESSUS_AUTH_METH  3 /* auth scheme, either 1 or 3 */
+#ifdef _WIN32
+#define NESSUS_KEYFILE    "~/nessus-keys.cfg"
+#define NESSUS_RCFILE     "~/nessusrc.cfg"
+#else
 #define NESSUS_KEYFILE    "~/.nessus.keys"
 #define NESSUS_RCFILE     "~/.nessusrc"
+#endif
 #define NESSUS_SIGKEYLEN  1024
 #define NESSUS_MINKEYLEN   512 /* used to check options, only */
 #endif
