@@ -15,9 +15,14 @@
    page nessus(1) about the -C option.\n\n"
 #endif
 
+
+#define CHANGE_PWD_BLURB "\n\
+   Enter your new passphrase.\n\n"
+
 char * pass_dialog (int);
 char * cmdline_pass (int);
 char * get_pwd (int);
 int created_private_key (void) ;
+char * keypass_dialog(int);
 
 #endif
