@@ -59,7 +59,7 @@ int preferences_init(prefs)
 static char * 
 preferences_get_filename()
 {
- if(Alt_rcfile)return Alt_rcfile;
+ if(Alt_rcfile)return estrdup(Alt_rcfile);
  else
   {
 #ifdef ENABLE_CRYPTO_LAYER
@@ -223,8 +223,8 @@ int preferences_process(filename,prefs)
 
 		   
 	}
-	buffer = emalloc(255);
-	while(!feof(fd) && fgets(buffer, 254,fd))
+	buffer = emalloc(4096);
+	while(!feof(fd) && fgets(buffer, 4096,fd))
 	  {
 	   if(strchr(buffer, '='))
 	    prefs_buffer_parse(buffer, prefs);
@@ -486,4 +486,15 @@ void prefs_check_defaults(prefs)
  struct arglist * prefs;
 {
 }
+
+
+int
+preferences_generate_new_file()
+{
+ preferences_new();
+ preferences_init(&Prefs);
+ pluginset_reload(Plugins, Scanners);
+ preferences_save(Prefs);
+ return 0;
+}
  
