@@ -273,6 +273,22 @@ void prefs_dialog_set_defaults(ctrls, preferences)
       v = s;
   } 
   gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(gtkw),(v && !strcmp(v, "yes")));
+
+ 
+  gtkw = arg_get_value(t, "SAVE_EMPTY_SESSIONS");
+  v = arg_get_value(serv, "save_empty_sessions");
+  if(arg_get_type(serv, "save_empty_sessions") == ARG_INT)
+  {
+      char * s = strdup(v ? "yes":"no");
+      arg_set_type(serv, "save_empty_sessions", ARG_STRING);
+      arg_set_value(serv, "save_empty_sessions", strlen(s), s);
+      v = s;
+  } 
+  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(gtkw),(v && !strcmp(v, "yes")));
+
+
+
+
 #endif 
  
  /*
@@ -343,6 +359,23 @@ void prefs_dialog_set_defaults(ctrls, preferences)
   v = arg_get_value(serv, "detached_scan");
   gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(gtkw), 0);
   
+  
+  gtkw = arg_get_value(t, "EMAIL_ADDR");
+  v = arg_get_value(serv, "detached_scan_email_address");
+  
+  if(arg_get_type(serv, "detached_scan_email_address") == ARG_INT)
+   {
+   char * s = strdup("");
+   arg_set_type(serv, "detached_scan_email_address", ARG_STRING);
+   arg_set_value(serv, "detached_scan_email_address", strlen(s), s);
+   }
+  else if(arg_get_type(serv, "detached_scan_email_address") < 0)
+   arg_add_value(serv, "detached_scan_email_address", ARG_STRING, 0, strdup(""));
+   
+  gtk_entry_set_text(GTK_ENTRY(gtkw), 
+  		arg_get_value(serv,"detached_scan_email_address"));
+  
+   
   gtkw = arg_get_value(t, "CONTINUOUS_SCAN");
   v = arg_get_value(serv, "continuous_scan");
   if(arg_get_type(serv, "continuous_scan")==ARG_INT)
@@ -531,6 +564,20 @@ int prefs_dialog_ok(w, ctrls)
    arg_set_value(serv, "save_session", strlen(s), s);
   else
    arg_add_value(serv, "save_session", ARG_STRING, strlen(s), s);
+   
+   
+   gtkw = arg_get_value(t, "SAVE_EMPTY_SESSIONS");
+  if(GTK_TOGGLE_BUTTON(gtkw) -> active)
+  	s = strdup("yes");
+  else
+  	s = strdup("no");
+
+  if(arg_get_value(serv, "save_empty_sessions"))
+   arg_set_value(serv, "save_empty_sessions", strlen(s), s);
+  else
+   arg_add_value(serv, "save_empty_sessions", ARG_STRING, strlen(s), s);
+   
+    
 #endif 
    
    s = gtk_entry_get_text(GTK_ENTRY(arg_get_value(t, "TARGET")));
@@ -551,8 +598,11 @@ int prefs_dialog_ok(w, ctrls)
    * Plugins preferences
    */
   {
-   struct arglist * plugs[2] = {Plugins, Scanners};
+   struct arglist * plugs[2];
    int i;
+   
+   plugs[0] = Plugins;
+   plugs[1] = Scanners;
    for(i=0;i<2;i++)
    {
     struct arglist  * plugins = plugs[i];
@@ -672,6 +722,12 @@ int prefs_dialog_ok(w, ctrls)
    else
     arg_add_value(serv, "detached_scan", ARG_STRING, strlen(s), s);  
   
+   gtkw = arg_get_value(t, "EMAIL_ADDR");
+   s = gtk_entry_get_text(GTK_ENTRY(gtkw));
+   arg_set_value(serv, "detached_scan_email_address", strlen(s), s);
+   
+   
+   
    gtkw = arg_get_value(t, "CONTINUOUS_SCAN");
   
    
