@@ -114,13 +114,16 @@ prefs_plugins_reset(ctrls, plugins, scanners)
  struct arglist * scanners;
 {
  struct arglist * prefs;
- struct arglist * s[2] = {scanners, plugins};
+ struct arglist * s[2];
  GtkWidget * frame;
  GtkWidget * s_window;
  GtkWidget * vbox;
  int i;
  
 
+ s[0] = plugins;
+ s[1] = scanners;
+ 
  if((!ctrls )|| (!plugins)||(!scanners))return;
  frame = arg_get_value(ctrls, "FRAME");
  s_window = arg_get_value(ctrls, "SCROLLED_WINDOW");
