@@ -326,8 +326,17 @@ static void do_create_report_window(args, interrupted_test, sorted_by_port)
 #ifdef ENABLE_SAVE_KB
 	if(DetachedMode)
 	{
+	 struct arglist * arg;
 	 show_info("nessusd is now scanning the remote network \n\
 in detached mode");
+  	 /*
+	  * Restore the login button
+	  */
+	 arg = arg_get_value(MainDialog, "AUTH");
+	 gtk_widget_hide(arg_get_value(arg, "CONNECTED"));
+	 gtk_widget_hide(arg_get_value(arg, "BUTTON_LOG_OUT"));
+	 gtk_widget_show(arg_get_value(arg, "BUTTON_LOG_IN"));
+	 GlobalSocket = -1;
 	}
 	else
 #endif		
@@ -860,11 +869,12 @@ save_report(nul,filew)
  switch(type)
  {
   case SAVE_HTML :
+  	arglist_to_html(hosts, fname);
+	break;
  case SAVE_XML :
 	arglist_to_xml(hosts, fname);
 	break;
-  	arglist_to_html(hosts, fname);
-	break;
+  	
  case SAVE_LATEX :
  	arglist_to_latex(hosts, fname);
 	break;
