@@ -60,7 +60,7 @@ void sighand_exit()
  {
    network_printf( "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
    shutdown(GlobalSocket, 2);
-   close(GlobalSocket);
+   closesocket(GlobalSocket);
    GlobalSocket = -1;
  }
  exit (1);
