@@ -58,6 +58,21 @@ extern u_short * getpts(char *);
 		PRIVATE FUNCTIONS
 		
 ********************************************************/
+
+
+static void 
+arg_addset_value(arg, name, type, len, value)
+ struct arglist *arg;
+ char * name;
+ int type, len;
+ void * value;
+{
+ if(arg_get_type(arg, name) < 0)
+  arg_add_value(arg, name, type, len, value);
+ else
+  arg_set_value(arg, name, len, value);
+}
+
 /*-------------------------------------------------------
 		
 		Determine if our father
@@ -71,7 +86,7 @@ is_father_alive(globals)
 {
  pid_t pid = (pid_t)arg_get_value(globals, "father");
  if(pid)
-  return kill(pid, 0);
+  return ! process_alive(pid);
  else
   return 0;
 }
@@ -235,6 +250,7 @@ attack_host      (globals,
 	 pl_class_t * cl_ptr = arg_get_value(plugins->value, "PLUGIN_CLASS");
 
 
+	 
 	 comm_send_status(globals, hostname, "attack", cur_plug++, num_plugs);
 #ifdef ENABLE_SAVE_KB
          if(save_kb(globals))
@@ -243,7 +259,17 @@ attack_host      (globals,
 	 			     "ID");
 	 int category = (int)arg_get_value(arg_get_value(plugins->value, "plugin_args"), 
 	 			     "CATEGORY");
-	 char * asc_id = emalloc(30);			     
+	 char * asc_id = emalloc(30);
+	 
+	 /*
+	  * Does our user want a differential scan only ?
+	  */
+	 if(diff_scan(globals))
+	 {
+	  diff_scan_enable(plugins->value);
+	 }
+	 
+	 			     
 	 sprintf(asc_id, "Launched/%d", id);
 	 if(arg_get_value(key, asc_id) &&
 	    !save_kb_replay_check(globals, category))
@@ -263,7 +289,7 @@ attack_host      (globals,
 	   continue;			
 	  }
 	  else {
-	  	arg_add_value(key, asc_id, ARG_INT, sizeof(int), (void*)1);
+	  	arg_addset_value(key, asc_id, ARG_INT, sizeof(int), (void*)1);
 		save_kb_write_int(globals, hostname, asc_id,  1);
 		}
 	efree(&asc_id);
@@ -302,9 +328,11 @@ attack_host      (globals,
 	  log_write("user %s : The remote host (%s) is dead\n",
 	  				attack_user_name(globals),
 	  				hostname);
+#ifdef ENABLE_SAVE_KB
+         if(new_kb)save_kb_close(globals, hostname);
+#endif
 	  return;
 	}
-	
         previous_plugin = plugins; 
        }
        
@@ -317,7 +345,7 @@ attack_host      (globals,
 				hostname, 
 				error);
 	
-	    free(error);	
+	    efree(&error);	
 	  }
       } /* if(plugins->launch) */
       plugins = plugins->next;
@@ -354,7 +382,13 @@ attack_start(args)
  int thread_socket = (int)arg_get_value(globals, "thread_socket");
  int soc;
  struct arglist * new_plugs = NULL;
+ struct attack_atom ** atoms = arg_get_value(args, "atoms");
+ struct timeval then, now;
  
+ gettimeofday(&then, NULL);
+ log_write("Starting to test %s\n", hostname);
+ 
+ attack_atom_free_others(atoms, hostname);
 
  /*
   * Options regarding the communication with out father
@@ -383,6 +417,17 @@ attack_start(args)
   attack_host(globals, hostinfos, new_plugs, hostname, port_range, hosts_list);
   if(preferences_ntp_show_end(preferences))ntp_11_show_end(globals, hostname);
      
+  gettimeofday(&now, NULL);
+  if(now.tv_usec < then.tv_usec)
+  {
+   then.tv_sec++;
+   now.tv_usec += 1000000;
+  }
+  log_write("Finished testing %s. Time : %ld.%ld secs\n",
+  		hostname,
+  		now.tv_sec - then.tv_sec,
+		now.tv_usec - then.tv_usec);
+		   
   shutdown(soc, 2);
   close(soc);
 }
@@ -436,10 +481,15 @@ attack_network(globals)
   detached = preferences_detached_scan(preferences);
   if(detached)
   {
+   char *email;
+   
+   detached_new_session(globals, arg_get_value(preferences, "TARGET"));
+   arg_addset_value(preferences, "ntp_keep_communication_alive", ARG_STRING, 0, NULL);
+   
    /* 
     * Tell the client that the scan is finished (actually, we will
-    * work hard to test the network, but this lazy client have the right
-    * to have some rest
+    * work hard to test the network, but this lazy client has the right
+    * to get some rest...
     */
    log_write("user %s : running a detached scan\n", arg_get_value(globals, "user"));
    global_socket = (int)arg_get_value(globals, "global_socket");
@@ -447,8 +497,22 @@ attack_network(globals)
    shutdown(global_socket, 2);
    global_socket = -1;
    arg_set_value(globals, "global_socket", sizeof(int), (void*)global_socket);
-  }
+
 start_attack_network:
+   if((email = preferences_detached_scan_email(preferences)))
+   {
+    /*
+     * The user wants to receive the results by e-mail.
+     */
+    if(detached_setup_mail_file(globals, email))
+    {
+     shutdown(global_socket, 2);
+     close(global_socket);
+     return;
+    }
+   }
+   else arg_addset_value(globals, "detached_scan_email_address", ARG_STRING, 0, NULL);
+  }
 #endif  
   num_tested = 0;
   num_threads = 0;
@@ -554,7 +618,10 @@ start_attack_network:
 #ifdef ENABLE_SAVE_TESTS  
   if(tested)
    while(hostname && 
-         harg_get_int(tested, hostname))hostname = hg_next_host(hg_globals, &host_ip);
+         harg_get_int(tested, hostname)){
+	 		efree(&hostname);
+			hostname = hg_next_host(hg_globals, &host_ip);
+			}
 #endif	
 
 
@@ -601,6 +668,7 @@ start_attack_network:
       log_write("user %s : not testing %s because it has never been tested before\n",
       		 arg_get_value(globals, "user"), 
 		 hostname);
+      efree(&hostname);
       hostname = hg_next_host(hg_globals, &host_ip);
       continue;
      }
@@ -612,6 +680,7 @@ start_attack_network:
      log_write("user %s : not testing %s because it has already been tested before\n", 
      			arg_get_value(globals, "user"), 
 			hostname);
+     efree(&hostname);			
      hostname = hg_next_host(hg_globals, &host_ip);
      continue;
     }
@@ -646,7 +715,8 @@ start_attack_network:
              arg_add_value(arglist, "plugins", ARG_ARGLIST, -1, plugins);
              arg_add_value(arglist, "port_range", ARG_STRING, -1, port_range);
              arg_add_value(arglist, "hosts_list", ARG_ARGLIST, -1, hosts_list); 
-	     pid = create_thread(attack_start, arglist, (struct arglist*)-1);   
+	     arg_add_value(arglist, "atoms", ARG_PTR, -1, atoms);
+	     pid = create_thread((void*)attack_start, arglist, (struct arglist*)-1); 
 	     nessusd_thread_register(threads, hostname, pid);
              num_threads++;
 	     log_write("user %s : testing %s [%d]\n", attack_user_name(globals), hostname, pid);
@@ -679,13 +749,14 @@ start_attack_network:
       if(!host_pending)
       {
         num_tested++;
-	free(hostname);
+	efree(&hostname);
        	hostname = hg_next_host(hg_globals, &host_ip);
 #ifdef ENABLE_SAVE_TEST	
 	if(tested)
 	 while(hostname &&
 	       harg_get_int(tested, hostname))
 		{
+		efree(&hostname);
 		hostname = hg_next_host(hg_globals, &host_ip);
 		}
 #endif		
@@ -759,20 +830,39 @@ start_attack_network:
 	
 stop:
 #ifdef ENABLE_SAVE_TESTS
-  if(save_session)save_tests_close(globals);
+  if(save_session){
+  	save_tests_close(globals);
+	if(!preferences_save_empty_sessions(preferences))
+	{
+	 if(save_tests_empty(globals))
+          {
+            log_write("user %s : Nothing interesting found - deleting the session\n",
+    		arg_get_value(globals, "user"));
+             save_tests_delete_current(globals);
+	  }
+        }
+   }
+   
+   
 #endif
   hg_cleanup(hg_globals);
   nessusd_threads_free(threads);
   attack_atom_free(atoms);
   arg_free_all(rejected_hosts);
 #ifdef ENABLE_SAVE_KB
+  if(detached)
+  {
+   if(preferences_detached_scan_email(preferences))
+    detached_send_email(globals);
+  }
+  
   if(continuous){
   	sleep(preferences_delay_between_scans(preferences));
-	plugins_free(plugins);
-	plugins = plugins_init(preferences);
+	plugins = plugins_reload(preferences, plugins);
 	arg_set_value(globals, "plugins", -1, plugins);
   	goto start_attack_network;
 	}
+  else if(detached)detached_end_session(globals);
 #endif	
   return(0);
 }
