@@ -96,7 +96,7 @@ auth_check_user(globals, from)
     if (l  &&  buf_password[l-1] == '\r')buf_password[--l] = '\0';
   }
 
-  if((permissions = check_user(usersdb, buf_user, buf_password))
+  if((permissions = check_user(usersdb, buf_user, buf_password, from))
      && (permissions != BAD_LOGIN_ATTEMPT))
   {
 	char* user = emalloc(strlen(buf_user)+1);
