@@ -32,6 +32,10 @@
 #include "ntp_11.h"
 #include "log.h"
 
+#ifdef ENABLE_SAVE_KB
+#include "detached.h"
+#endif
+
 #ifdef ENABLE_CRYPTO_LAYER
 #include "peks/peks.h"
 #include "nsp.h"
@@ -268,14 +272,33 @@ comm_send_preferences(globals)
  
  /* We have to be backward compatible with the NTP/1.0 */
  auth_printf(globals, "SERVER <|> PREFERENCES <|>\n");
+
  while(prefs && prefs->next)
  {
   if (prefs->type == ARG_STRING) 
-  auth_printf(globals, "%s <|> %s\n", prefs->name, (const char *) prefs->value);
+   {
+     /*
+      * No need to send nessusd-specific preferences
+      */
+     if( strcmp(prefs->name, "logfile")           &&
+         strcmp(prefs->name, "config_file")       &&
+         strcmp(prefs->name, "plugins_folder")    &&
+	 strcmp(prefs->name, "dumpfile")          &&
+	 strcmp(prefs->name, "users")             &&
+	 strcmp(prefs->name, "rules")             &&
+	 strncmp(prefs->name, "peks_", 5)         &&
+	 strcmp(prefs->name, "negot_timeout")     &&
+	 strcmp(prefs->name, "cookie_logpipe")    &&
+	 strcmp(prefs->name, "force_pubkey_auth") &&
+	 strcmp(prefs->name, "log_while_attack")  &&
+	 strcmp(prefs->name, "log_plugins_name_at_load"))  
+    		auth_printf(globals, "%s <|> %s\n", prefs->name, (const char *) prefs->value);
+  }
   prefs = prefs->next;
  }
 #ifdef ENABLE_SAVE_TESTS
  auth_printf(globals, "ntp_save_sessions <|> yes\n");
+ auth_printf(globals, "ntp_detached_sessions <|> yes\n");
 #endif
  auth_printf(globals, "<|> SERVER\n");
 }
