@@ -19,6 +19,8 @@
  * Author: Jordan Hrycaj <jordan@mjh.teddy-net.com>
  *
  * Some stuff extracted from nessusd.c
+ *
+ * $Id: crypto-layer.c,v 1.25 2000/12/29 02:19:51 jordan Exp $
  */
 
 #include <includes.h>
@@ -71,7 +73,7 @@ svc_log_write
   int dim, n, c;
 
   /* test argument stack */
-  while ((c = psvc_get_nextx (data, (void **)&av, &dim)) == 'S')
+  while ((c = psvc_get_nextx (data, (void **)&av, (unsigned int*)&dim)) == 'S')
     for (n = 0; n < dim; n ++)
       log_write ("<%s@%s> %s", usr, ipadd, av [n]) ;
   
@@ -121,7 +123,7 @@ get_pwd
 }
 
 static char *
-pass_dialog ()
+pass_dialog (int s)
 {
   return setpwd;
 }
@@ -259,7 +261,18 @@ cipher_stuff_init
   peks_key *key;
   const char *user, *rpcu, *file, *devrnd ;
   int klen ;
- 
+
+  /* suppress path checking */
+  int saccess = (int)arg_get_value (opts, "suppr_acc");
+  int do_hint = (int)arg_get_value (opts, "acc_hint");
+
+# if 1 /* XXXXXXXXXXXXXXXXXX */
+  /* do not check directory paths for versions == 1.0.7 */
+# include "corevers.h"
+  if (strcmp (NESSUS_VERSION, "1.0.7") == 0)
+    peks_admin_equiv (-1,-1);
+# endif
+
   /* overwrite defaults by config */
          arg_reorg_s2i  (prefs, "peks_pwdfail",  NESSUSD_MAXPWDFAIL) ;
   klen = arg_reorg_s2i  (prefs, "peks_keylen",   NESSUSD_KEYLENGTH) ;
@@ -282,8 +295,23 @@ cipher_stuff_init
   }
 
   if ((key = peks_private_key (user, file, get_pwd, klen)) == 0) {
-    print_error("%s - aborting.\n", peks_strerr (errno));
-    DO_EXIT (1);
+    int prterr = errno ;
+    if (saccess) {
+      peks_admin_equiv (-1,-1);
+      key = peks_private_key (user, file, get_pwd, klen);
+    }
+    if (key == 0) {
+      print_error ("%s - aborting.\n", peks_strerr (errno));
+      if (saccess == 0)
+	print_error ("\n *** If this is unavoidable, you may try "
+		     "restarting with the "
+		     "--suppress-cfg-check option!\n\n");
+      DO_EXIT (1);
+    }
+    if (do_hint)
+      print_error ("WARNING: %s.\n"
+		   "     ... retrying without path check "
+		   "as requested!\n\n", peks_strerr (prterr));
   }
 
   /* store key for global use */
@@ -327,6 +355,9 @@ do_local_cipher_commands (opts, prefs)
   char *kill_userkey = arg_get_value (opts,  "kill_userkey");
   int chng_pph =  (int)arg_get_value (opts,  "chng_pph");
   int list_udb =  (int)arg_get_value (opts,  "list_udb");
+  int saccess  =  (int)arg_get_value (opts, "suppr_acc");
+  int do_hint  =  (int)arg_get_value (opts, "acc_hint");
+  char *key_expfile  = arg_get_value (opts,  "key_expfile");
   peks_key *key      = arg_get_value (prefs, "peks_key");
   char * s;
 
@@ -337,7 +368,7 @@ do_local_cipher_commands (opts, prefs)
   if (list_upwd != 0) {
     verify_root_access ();
     if ((s = peks_edit_passwd_file
-	 (key, list_upwd, -1, 0, arg_get_value (prefs, "peks_usrkeys"))) == 0) {
+	 (key, list_upwd, -1,0, arg_get_value (prefs, "peks_usrkeys"))) == 0) {
       print_error("ERROR: %s.\n", peks_strerr (errno));
       DO_EXIT (1);
     }
@@ -398,6 +429,30 @@ do_local_cipher_commands (opts, prefs)
     }
     did_something ++ ;
   }
+
+  /* export public key */
+  if (key_expfile != 0) {
+    if (peks_save_public_key ("@127.0.0.1", key, key_expfile) < 0) {
+      int prterr = errno, n = -1 ;
+      if (saccess) {
+	peks_admin_equiv (-1,-1);
+	n = peks_save_public_key ("@127.0.0.1", key, key_expfile);
+      }
+      if (n < 0) {
+	print_error("ERROR: %s.\n", peks_strerr (errno));
+	if (saccess == 0)
+	  print_error ("\n *** If this is unavoidable, you may try "
+		       "restarting with the "
+		       "--suppress-cfg-check option!\n\n");
+	DO_EXIT (1);
+      }
+      if (do_hint)
+	print_error ("WARNING: %s.\n"
+		     "     ... retrying without path check "
+		     "as requested!\n\n", peks_strerr (prterr));
+    }
+    did_something ++ ;
+  }
  
   if (did_something)
     DO_EXIT (0) ;
@@ -533,9 +588,14 @@ install_pipe_logger
 
   /* clean up resources from server defs */
   {
+    extern int g_iana_socket;
+#   ifdef DEFAULT_PORT /* migration */
     extern int g_serv_socket;
     if (g_serv_socket >= 0)
       close (g_serv_socket) ;
+#   endif
+    if (g_iana_socket >= 0)
+      close (g_iana_socket) ;
     if ((n = (int)arg_get_value (globs, "global_socket")) > 0)
       close (n) ;
   }
@@ -748,7 +808,7 @@ rpc_log_write
 
   else
     /* check return code from application */
-    if ((c = psvc_get_nextx (args, (void **)&av, &n)) > 0) {
+    if ((c = psvc_get_nextx (args, (void **)&av, (unsigned int*)&n)) > 0) {
       if (c != 'S')
 	print_error
 	  ("rpc_log_write: Unexpecterd return code of type %c.\n", c);
