@@ -39,7 +39,7 @@ static int current_nasl_plugin = -1;
 static void nasl_thread(struct arglist *);
 
 static 
-void nasl_plugin_sigterm()
+void nasl_plugin_sigterm(int s)
 {
  if(current_nasl_plugin >= 0)
  {
@@ -122,16 +122,16 @@ nasl_plugin_launch(globals, plugin, hostinfos, preferences, kb, name)
  int pip[2];
  int category = 0;
  nthread_t module;
- 
- harglst * nasl = init_nasl(preferences_get_checks_read_timeout(preferences));
- harglst * variables = harg_get_harg(nasl, "variables");
- harglst * types = harg_get_harg(nasl, "variables_types");
  struct arglist * d = emalloc(sizeof(struct arglist));
  short* ports = arg_get_value(globals, "ports");
  int ports_num = (int)arg_get_value(globals, "ports_num");
- char * buf = emalloc(512);
+ int i;
+ 
  socketpair(AF_UNIX, SOCK_STREAM, 0, pip);
  args = arg_get_value(plugin, "plugin_args");
+ 
+
+ 
  arg_add_value(args, "HOSTNAME", ARG_ARGLIST, -1, hostinfos);
  if(arg_get_value(args, "globals"))
    arg_set_value(args, "globals", -1, globals);
@@ -144,37 +144,51 @@ nasl_plugin_launch(globals, plugin, hostinfos, preferences, kb, name)
  arg_set_value(args, "preferences", -1, preferences);
  arg_add_value(args, "pipe", ARG_INT, sizeof(int), (void*)pip[1]);
  arg_add_value(args, "key", ARG_ARGLIST, -1, kb);
- timeout = (int)arg_get_value(args, "TIMEOUT");
- harg_add_ptr(nasl, "script_infos", args);
+
+ arg_add_value(d, "args", ARG_ARGLIST, -1, args);
+ arg_add_value(d, "name", ARG_STRING, -1, name);
  
+ category = (int)arg_get_value(args, "CATEGORY");
+ timeout = preferences_plugin_timeout(preferences,(int)arg_get_value(args, "ID"));
+ if(!timeout)
+ {
+  if(category == ACT_SCANNER)timeout = -1;
+  else timeout = preferences_plugins_timeout(preferences);
+ }
+
+ current_nasl_plugin = module = create_thread((void*)nasl_thread, d, (struct arglist*)-1); 
+ signal(SIGTERM, nasl_plugin_sigterm);
+ thread_timeout(globals, module, timeout, pip[0], kb);
+ current_nasl_plugin = -1;
+
+ close(pip[0]);
+ close(pip[1]);
+ arg_free(d);
+}
+
+
+static void nasl_thread(g_args) 
+ struct arglist * g_args;
+{
+ struct arglist * args = arg_get_value(g_args, "args");
+ struct arglist * globals = arg_get_value(args, "globals");
+ struct arglist * preferences = arg_get_value(globals, "preferences");
+ char * name = arg_get_value(g_args, "name");
+ harglst * nasl;
+ harglst * variables;
+ harglst * types;
+ 
+ 
+ nasl = init_nasl(preferences_get_checks_read_timeout(preferences));
+ variables = harg_get_harg(nasl, "variables");
+ types = harg_get_harg(nasl, "variables_types");
  
  harg_add_string(variables, "description", "0");
  harg_add_int(types,"description", VAR_STR|STR_ALL_DIGIT);
  
- arg_add_value(d, "nasl", ARG_ARGLIST, -1, nasl);
- arg_add_value(d, "name", ARG_STRING, -1, name);
- 
- if(category == ACT_SCANNER)timeout = -1;
- else if(!timeout)timeout = preferences_plugins_timeout(preferences);  
- 
- current_nasl_plugin = module = create_thread(nasl_thread, d, (struct arglist*)-1); 
- signal(SIGTERM, nasl_plugin_sigterm);
- thread_timeout(globals, module, timeout, pip[0], kb);
- current_nasl_plugin = -1;
- free(buf);
- close(pip[0]);
- close(pip[1]);
- arg_free(d);
- nasl_exit(nasl);
-}
-
-
-static void nasl_thread(args) 
- struct arglist * args;
-{
- char * name = arg_get_value(args, "name");
- harglst * nasl = arg_get_value(args, "nasl");
+ harg_add_ptr(nasl, "script_infos", args);
  execute_script(nasl, name);
+ nasl_exit(nasl);
 }
 
 
