@@ -31,7 +31,7 @@
 static int current_nes_plugin = -1;
 
 static
-void nes_plugin_sigterm()
+void nes_plugin_sigterm(int s)
 {
  if(current_nes_plugin >= 0)
  {
@@ -42,14 +42,14 @@ void nes_plugin_sigterm()
 }
 
 #ifdef HAVE_SHL_LOAD	/* this is HP/UX */
-ext_library_ptr dlopen(name)
+ext_library_t dlopen(name)
  char* name;
 {
- return (ext_library_ptr)shl_load(name, BIND_IMMEDIATE|BIND_VERBOSE|BIND_NOSTART, 0L);
+ return (ext_library_t)shl_load(name, BIND_IMMEDIATE|BIND_VERBOSE|BIND_NOSTART, 0L);
 }
 
 void * 
-dlsym(p, name)
+dlsym(lib, name)
  shl_t lib;
  char * name;
 {
@@ -185,13 +185,18 @@ nes_plugin_launch(globals, plugin, hostinfos, preferences, kb, name)
  arg_set_value(args, "preferences", -1, preferences);
  arg_add_value(args, "pipe", ARG_INT, sizeof(int), (void*)pip[1]);
  arg_add_value(args, "key", ARG_ARGLIST, -1, kb);
- timeout = (int)arg_get_value(args, "TIMEOUT");
  
- if(category == ACT_SCANNER)timeout = -1;
- else if(!timeout)timeout = preferences_plugins_timeout(preferences);
+ timeout = preferences_plugin_timeout(preferences,(int)arg_get_value(args, "ID"));
+ 
+ category = (int)arg_get_value(args, "CATEGORY");
+ if(!timeout)
+ {
+  if(category == ACT_SCANNER)timeout = -1;
+  else timeout = preferences_plugins_timeout(preferences);
+ }
  
  
- current_nes_plugin = module = create_thread(func, args, (struct arglist*)-1);
+ current_nes_plugin = module = create_thread((void*)func, args, (struct arglist*)-1);
  signal(SIGTERM, nes_plugin_sigterm);
  thread_timeout(globals, module, timeout, pip[0], kb);
  current_nes_plugin = -1;
