@@ -48,6 +48,9 @@ static int ntp_11_long_attack(struct arglist *, char *);
 static int ntp_11_list_sessions(struct arglist*);
 static int ntp_11_delete_session(struct arglist*, char*);
 static int ntp_11_restore_session(struct arglist*, char*);
+
+static int ntp_11_list_detached_sessions(struct arglist *, char *);
+static int ntp_11_stop_detached_session(struct arglist*, char*);
 #endif
 /*
  * Parses the input sent by the client before
@@ -85,6 +88,16 @@ int ntp_11_parse_input(globals, input)
   if(!strcmp(input, "SESSION_RESTORE")) {
   	return ntp_11_restore_session(globals, orig);
 	}
+	
+  if(!strcmp(input, "STOP_DETACHED")) {
+  	ntp_11_stop_detached_session(globals, orig);
+	return 1;
+	}
+
+  if(!strcmp(input, "DETACHED_SESSIONS_LIST")) {
+  	ntp_11_list_detached_sessions(globals, orig);
+	return 1;
+	}
 #endif
   if(!strcmp(input, "LONG_ATTACK")){
   	return ntp_11_long_attack(globals, orig);
@@ -161,10 +174,10 @@ static int ntp_11_read_prefs(globals)
 {
  struct arglist *  preferences = arg_get_value(globals, "preferences");
  int soc = (int)arg_get_value(globals, "global_socket");
- char input [4096];
+ static char input [32768];
 
  for (;;) {
-
+   bzero(input, sizeof(input));
    recv_line (soc, input, sizeof (input)-1);
    /* auth_gets(globals, input, 4095); */
 
@@ -196,6 +209,23 @@ static int ntp_11_read_prefs(globals)
       v[0] = 0;
     
       value = v + 5;
+      /*
+       * "system" prefs can't be changed
+       */
+      if(!strcmp(pref, "logfile")           ||
+         !strcmp(pref, "config_file")       ||
+         !strcmp(pref, "plugins_folder")    ||
+	 !strcmp(pref, "dumpfile")          ||
+	 !strcmp(pref, "users")             ||
+	 !strcmp(pref, "rules")             ||
+	 !strncmp(pref, "peks_", 5)         ||
+	 !strcmp(pref, "negot_timeout")     ||
+	 !strcmp(pref, "cookie_logpipe")    ||
+	 !strcmp(pref, "force_pubkey_auth") ||
+	 !strcmp(pref, "log_while_attack")  ||
+	 !strcmp(pref, "log_plugins_name_at_load"))
+      	continue;
+      
       old = arg_get_value(preferences, pref);
 #ifdef DEBUGMORE     
       printf("%s - %s (old : %s)\n", pref, value, old);
@@ -344,6 +374,69 @@ extract_session_key_from_session_msg(globals, orig)
 }
 
 
+static int
+extract_detached_session_key_from_session_msg(globals, orig)
+ struct arglist * globals;
+ char * orig;
+{
+ char * t;
+ int i, len;
+
+ t = strrchr(orig, '<');
+ if(!t)return -1;
+ t[0] = 0;
+ 
+ t = strrchr(orig, '>');
+ if(!t)return -1;
+
+ t++;
+ while(t[0]==' ')t++;
+ while(t[strlen(t)-1]==' ')t[strlen(t)-1]=0;
+ 
+ /*
+  * Sanity check. All detached sessions name are under the form
+  * of a pid.
+  */
+ len = strlen(t);
+ for(i=0;i<len;i++)
+  if(!isdigit(t[i])){
+  	log_write("user %s : supplied an incorrect detached session name (%s)",
+			(char*)arg_get_value(globals, "user"),
+			t);
+  	return -1;
+	}
+ return atoi(t);
+}
+
+
+
+static int
+ntp_11_stop_detached_session(globals, orig)
+ struct arglist * globals;
+ char * orig;
+{
+ int session = 0;
+ int ret;
+ 
+ session = extract_detached_session_key_from_session_msg(globals, orig);
+ if(session < 0)return -1;
+ 
+ ret = detached_delete_session(globals, session);
+ return 0;
+}
+
+static int
+ntp_11_list_detached_sessions(globals, orig)
+ struct arglist * globals;
+ char * orig;
+{
+ auth_printf(globals, "SERVER <|> DETACHED_SESSIONS_LIST\n");
+ detached_send_sessions(globals);
+ auth_printf(globals, "<|> SERVER\n");
+ return 0;
+}
+
+
 static int
 ntp_11_delete_session(globals, orig)
  struct arglist * globals;
@@ -381,9 +474,7 @@ static int
 ntp_11_list_sessions(globals)
  struct arglist * globals;
 {
- 
- 
- auth_printf(globals, "SERVER <|> SESSION_LIST\n");
+ auth_printf(globals, "SERVER <|> SESSIONS_LIST\n");
  save_tests_send_list(globals);
  auth_printf(globals, "<|> SERVER\n");
  return 0;
