@@ -37,6 +37,9 @@ piic_parse(globals, args, pip, buf)
  char * t;
  int type;
  char *c;
+ if(!buf)
+  return;
+  
  if(buf[strlen(buf)-1]=='\n')buf[strlen(buf)-1]=0;
  c = strrchr(buf, ';');
  if(c)c[0] = 0;
@@ -72,8 +75,11 @@ piic_parse(globals, args, pip, buf)
      */
     if(this_type == ARG_STRING)
     {
+     char * t = arg_get_value(args, name);
+     if(t){
      if(!strcmp(arg_get_value(args, name), value))
       return;
+      }
      }
      else if(this_type == ARG_INT)
      {
@@ -122,7 +128,7 @@ int piic_read_socket(globals, args, soc)
  struct arglist * globals, *args;
  int soc;
 {
- char buf[2048];
+ static char buf[2048];
  fd_set rd;
  struct timeval tv;
 
@@ -133,8 +139,8 @@ int piic_read_socket(globals, args, soc)
  FD_SET(soc, &rd);
  if((select(soc+1, &rd, NULL, NULL, &tv))>0)
  {
-  bzero(buf, 2048);
-  recv_line(soc, buf, 2047);
+  bzero(buf, sizeof(buf));
+  recv_line(soc, buf, sizeof(buf) - 1);
   piic_parse(globals, args, soc, buf);
   return 1;
  }
