@@ -40,6 +40,16 @@ static pl_class_t* plugin_classes = NULL;
 struct arglist * 
 plugins_init(preferences)
  struct arglist * preferences;
+{
+ return plugins_reload(preferences, emalloc(sizeof(struct arglist)));
+}
+
+
+
+struct arglist * 
+plugins_reload(preferences, plugins)
+ struct arglist * preferences;
+ struct arglist * plugins;
 {
 #ifndef NESSUSNT
   DIR * dir;
@@ -50,10 +60,9 @@ plugins_init(preferences)
   HANDLE search;
   int finished = 0;
 #endif
-  struct arglist * plugins;
-  struct arglist * ret;
   char * folder = arg_get_value(preferences, "plugins_folder");
   
+
   if(!plugin_classes){
    pl_class_t ** cl_pptr = &plugin_classes;
    pl_class_t * cl_ptr;
@@ -84,7 +93,7 @@ plugins_init(preferences)
 #endif
       print_error("could not determine the value of <plugins_folder>. Check %s\n",
       	(char *)arg_get_value(preferences, "config_file"));
-      DO_EXIT(0);
+      return plugins;
     }
 #ifndef NESSUSNT
   if(!(dir = opendir(folder)))
@@ -96,9 +105,9 @@ plugins_init(preferences)
     {
       print_error("Couldn't open the directory called \"%s\"\nCheck %s\n", folder,
       		   (char *)arg_get_value(preferences, "config_file"));
-      DO_EXIT(1);
+      return plugins;
     }
-  ret = emalloc(sizeof(struct arglist));
+ 
   /*
    * Add the the plugins
    */
@@ -113,12 +122,15 @@ plugins_init(preferences)
 #endif
 	pl_class_t * cl_ptr = plugin_classes;
 	
+
+	if(!arg_get_value(plugins, name))
+	{
 	if(preferences_log_plugins_at_load(preferences))
 	 log_write("Loading %s\n", name);
 	while(cl_ptr) {
          int elen = strlen(cl_ptr->extension);
 	 if((len > elen) && !strcmp(cl_ptr->extension, name+len-elen)) {
-	 	struct arglist * pl = (*cl_ptr->pl_add)(folder, name,ret,
+	 	struct arglist * pl = (*cl_ptr->pl_add)(folder, name,plugins,
 							preferences);
    		if(pl) {
 			arg_add_value(pl, "PLUGIN_CLASS", ARG_PTR,
@@ -127,6 +139,7 @@ plugins_init(preferences)
 		break;
 	}
 	cl_ptr = cl_ptr->pl_next;
+      }
      }
     }
 #ifdef NESSUSNT
@@ -137,13 +150,14 @@ plugins_init(preferences)
 #endif
  
   
-  plugins = sort_plugins_by_type(rasort(sort_plugins_by_type(ret)));
+  plugins = sort_plugins_by_type(rasort(sort_plugins_by_type(plugins)));
   closedir(dir);
   return plugins;
 }
 
 
 
+
 void 
 plugin_set_socket(struct arglist * plugin, int soc)
 {
@@ -168,6 +182,9 @@ plugins_free(plugins)
  {
   struct arglist * args = arg_get_value(plugins->value, "plugin_args");
   struct arglist * next;
+  struct arglist * sublist = plugins->value;
+  
+ 
   while(args && args->next)
   {
    if(args->type == ARG_STRING)efree(&args->value);
@@ -176,12 +193,25 @@ plugins_free(plugins)
    efree(&args);
    args = next;
  }
- efree(&plugins->value);
+ 
+ while(sublist && sublist->next)
+ {
+  if(sublist->type == ARG_STRING)efree(&sublist->value);
+  efree(&sublist->name);
+  next = sublist->next;
+  efree(&sublist);
+  sublist = next;
+ }
+
+ 
+ efree(&next);
  efree(&plugins->name);
  next = plugins->next;
  efree(&plugins);
  plugins = next;
  }
+ if(plugins)
+  efree(&plugins);
 }
 /*
  * Put our socket somewhere in the plugins
