@@ -50,7 +50,6 @@ int preferences_new(char * name)
 {
   FILE * fd;
   int f;
-  char * hn;
 
   if((f = open(name, O_CREAT | O_RDWR | O_EXCL, 0660))<0){
     perror("open ");
@@ -59,9 +58,6 @@ int preferences_new(char * name)
 
   fd = fdopen(f, "w");
   
-  hn = emalloc(255);
-  gethostname(hn, 254);
-	
  fprintf(fd, "# Configuration file of the Nessus Security Scanner\n\n\n\n");
  fprintf(fd, "# Every line starting with a '#' is a comment\n\n");
  fprintf(fd, "# Path to the security checks folder : \n");
@@ -111,6 +107,13 @@ int preferences_new(char * name)
  fprintf(fd, "# Maximum lifetime of a plugin (in seconds) : \n");
  fprintf(fd, "plugins_timeout = %d\n", PLUGIN_TIMEOUT);
 #ifdef ENABLE_SAVE_KB 
+#ifdef DEFAULT_PORT /* migration */
+ fprintf(fd, "\n\n#--- Migration to the IANA assigned nessus port 1241\n");
+ fprintf(fd, "# http://www.isi.edu/in-notes/iana/assignments/port-numbers\n");
+ fprintf(fd, "# NOTE: You need to restart the server after a change of\n");
+ fprintf(fd, "# this particular field (HUP won't work, here.)\n");
+ fprintf(fd, "disable_3001compat = no\n");
+#endif
  fprintf(fd, "\n\n#--- Knowledge base saving (can be configured by the client) :\n");
  fprintf(fd, "# Save the knowledge base on disk : \n");
  fprintf(fd, "save_knowledge_base = yes\n");
@@ -119,7 +122,7 @@ int preferences_new(char * name)
  fprintf(fd, "# Only test hosts whose KB we do not have :\n");
  fprintf(fd, "only_test_hosts_whose_kb_we_dont_have = no\n");
  fprintf(fd, "# Only test hosts whose KB we already have :\n");
- fprintf(fd, "only_test_hosts_whose_kb_we_have = yes\n");
+ fprintf(fd, "only_test_hosts_whose_kb_we_have = no\n");
  fprintf(fd, "# KB test replay :\n");
  fprintf(fd, "kb_dont_replay_scanners = no\n");
  fprintf(fd, "kb_dont_replay_info_gathering = no\n");
@@ -129,7 +132,6 @@ int preferences_new(char * name)
  fprintf(fd, "#--- end of the KB section\n");
 #endif 
  fprintf(fd, "#end.\n");
-  efree(&hn);
   fclose(fd);
   close(f);
   return(0);
@@ -321,13 +323,30 @@ preferences_plugins_timeout(preferences)
 {
  char * pref = arg_get_value(preferences, "plugins_timeout");
  if(pref)
-  {
-   if(atoi(pref))return atoi(pref);
-  }
- return PLUGIN_TIMEOUT;
+   return atoi(pref);
+ else
+  return PLUGIN_TIMEOUT;
 }
 
 
+int
+preferences_plugin_timeout(preferences, id)
+ struct arglist * preferences;
+ int id;
+{
+ int ret = 0;
+ char * pref_name = emalloc(strlen("timeout.") + 40);
+ 
+ sprintf(pref_name, "timeout.%d", id);
+ if(arg_get_type(preferences, pref_name) == ARG_STRING)
+ {
+  int to = atoi(arg_get_value(preferences, pref_name));
+  if(to)ret = to;
+ }
+ efree(&pref_name);
+ return ret;
+}
+
 #ifdef ENABLE_SAVE_TESTS
 int 
 preferences_save_session(preferences)
@@ -339,6 +358,19 @@ preferences_save_session(preferences)
  else
   return 0;
 }
+
+int 
+preferences_save_empty_sessions(preferences)
+ struct arglist * preferences;
+{
+ char * pref = arg_get_value(preferences, "save_empty_sessions");
+ if(pref && !strcmp(pref, "yes"))
+  return 1;
+ else
+  return 0;
+}
+
+
 #endif
 
 
@@ -381,4 +413,17 @@ preferences_delay_between_scans(preferences)
  }
  return 3600;
 }
+
+
+char *
+preferences_detached_scan_email(preferences)
+ struct arglist * preferences;
+{
+ char * pref = arg_get_value(preferences, "detached_scan_email_address");
+
+ if(pref && strlen(pref) && strcmp(pref, "no"))
+  return pref;
+ else
+  return NULL;
+}
 #endif
