@@ -23,6 +23,10 @@
 struct nessus_rules
 	{
 	 struct in_addr ip;
+	 int client_ip;	/*  if set to 1, then 'ip' will be replaced by
+			    the client ip when appropriate
+			 */   
+
 	 int mask;
 	 int rule; 
 	 int def; 	/* default */
@@ -33,10 +37,11 @@ struct nessus_rules
 #define RULES_REJECT 2
 #define CAN_TEST(x) (x==RULES_ACCEPT)
 void rules_init(struct nessus_rules **, struct arglist *);
-void rules_add(struct nessus_rules **, struct nessus_rules **);
+void rules_add(struct nessus_rules **, struct nessus_rules **, char*);
 struct nessus_rules * rules_parse(char * , struct nessus_rules *, int);
 struct nessus_rules * rules_dup(struct nessus_rules *);
 void rules_set_def(struct nessus_rules *, int);
-int get_host_rules(struct nessus_rules *, struct in_addr, int );
+void rules_set_client_ip(struct nessus_rules *, struct in_addr);
+int get_host_rules(struct nessus_rules *, struct in_addr, int);
 
 #endif
