@@ -131,8 +131,14 @@ void sighand_pipe()
 
 void sighand_chld()
 {
-  wait(NULL);
-  let_em_die (0);
+	int max_iterations = 2000;
+	int i = 0;
+	while(waitpid(0, NULL, WNOHANG) > 0)
+	{
+		i++;
+		if(i > max_iterations)
+			break;
+	}
 }
 
 void sighand_alarm()
