@@ -28,7 +28,7 @@ struct users {
 
 #define BAD_LOGIN_ATTEMPT (struct nessus_rules*)(-1)
 
-int users_init(struct users **, struct arglist *);
-struct nessus_rules * check_user(struct users *, char * , char *);
+int users_init(struct users **, struct arglist *, int silent);
+struct nessus_rules * check_user(struct users *, char * , char *, char *);
 void users_add_rule(struct nessus_rules *, char *);
 #endif
