@@ -58,39 +58,22 @@ int
 version_check(a,b)
  char * a, *b;
 {
- int major_a = 0, minor_a = 0, patch_a = 0;
- int major_b = 0, minor_b = 0, patch_b = 0;
+ int int_a, int_b;
  
- major_a = atoi(a);
- a = strchr(a, '.');
- if(a)
- {
-  minor_a = atoi(a+sizeof(char));
-  a = strchr(a+sizeof(char), '.');
-  if(a)patch_a = atoi(a+sizeof(char));
+ if(!a || !b) return -2; 
+ 
+ int_a = atoi(a);
+ int_b = atoi(b);
+ 
+ if(int_a < int_b) return -1;
+ if(int_a > int_b) return 1;
+ else {
+  char * dot_a = strchr(a, '.'), * dot_b = strchr(b, '.');
+  if(dot_a && dot_b)
+   return version_check(&(dot_a[1]), &(dot_b[1]));
+  else 
+   return -2;
  }
- 
- major_b = atoi(b);
- b = strchr(b, '.');
- if(b)
- {
-  minor_b = atoi(b+sizeof(char));
-  b = strchr(b+sizeof(char), '.');
-  if(b)patch_b = atoi(b+sizeof(char));
- }
- 
- if(major_a < major_b)return -1;
- if(major_a > major_b)return 1;
- 
- /* major are the same */
- if(minor_a < minor_b)return -1;
- if(minor_a > minor_b)return 1;
- 
- /* minor are the sames */
- if(patch_a < patch_b)return -1;
- if(patch_a > patch_b)return 1;
- 
- return 0;
 }
 
  
@@ -101,7 +84,8 @@ version_check(a,b)
  * not seeking the best performances right now, well, it fits my need
  *
  */
-struct arglist * sort_plugins_by_type(lplugs)
+struct arglist * 
+sort_plugins_by_type(lplugs)
  struct arglist * lplugs;
 {
  struct arglist * plugins = lplugs;
@@ -141,7 +125,8 @@ struct arglist * sort_plugins_by_type(lplugs)
  * the user allowed us to use. If it's not
  * set correctly, we return 5
  */
-int get_max_thread_number(preferences)
+int 
+get_max_thread_number(preferences)
  struct arglist * preferences;
 {
   int max_threads;
@@ -184,7 +169,8 @@ get_active_plugins_number(plugins)
 }
 
 
-void send_plugin_order(globals, plugins)
+void 
+send_plugin_order(globals, plugins)
  struct arglist * globals;
  struct arglist * plugins;
 {
@@ -218,7 +204,8 @@ void send_plugin_order(globals, plugins)
 }
 
 
-void plugins_set_ntp_caps(plugins, caps)
+void 
+plugins_set_ntp_caps(plugins, caps)
  struct arglist * plugins;
  ntp_caps* caps;
 {
@@ -255,7 +242,10 @@ attack_atom_free(atoms)
  struct attack_atom ** atoms;
 {
  struct attack_atom * a;
- if(!atoms)return;
+ if(!atoms)
+  return;
+ 
+ 
  a = *atoms;
  while(a)
  { 
@@ -270,6 +260,37 @@ attack_atom_free(atoms)
  efree(&atoms);
 }
 
+
+void
+attack_atom_free_others(atoms, name)
+ struct attack_atom ** atoms;
+ char * name;
+{
+ struct attack_atom *a;
+ 
+ if(!atoms)
+  return;
+  
+ a = *atoms;
+ while(a)
+ {
+  struct attack_atom *b;
+  b = a->next;
+  if(!strcmp(a->name, name))
+  {
+   *atoms = a;
+   a->next = NULL;
+  }
+  else
+  {
+   efree(&a->name);
+   close(a->soc);
+   close(a->psoc);
+  }
+  a = b;
+ }
+}
+
 void
 attack_atom_insert(atoms, name, soc, psoc)
  struct attack_atom** atoms;
@@ -278,7 +299,7 @@ attack_atom_insert(atoms, name, soc, psoc)
 {
  struct attack_atom * atom =  emalloc(sizeof(struct attack_atom));
  
- atom->name = strdup(name);
+ atom->name = estrdup(name);
  atom->soc = soc;
  atom->psoc = psoc;
  
@@ -313,12 +334,21 @@ attack_atom_remove(atoms, name)
  struct attack_atom ** atoms;
  char * name;
 {
- struct attack_atom * a = *atoms;
+ struct attack_atom * a;
  
- if(!a)
+ if(!atoms)
   return;
   
- if(!strcmp(a->name, name))
+ a = *atoms;
+ 
+ if(!a || !name)
+  {
+  log_write("*** %s:%d trying to remove '%s' from 0x%x\n", 
+  		__FILE__, __LINE__, name, a);
+  return;
+  }
+  
+ if(a->name && !strcmp(a->name, name))
  {
   *atoms = a->next;
   close(a->soc);
@@ -330,10 +360,10 @@ attack_atom_remove(atoms, name)
  {
   while(a->next)
   {
-  if(!strcmp(a->next->name, name))
+  if(a->next->name && !strcmp(a->next->name, name))
   {
    struct attack_atom * b = a->next;
-   a->next = b->next;
+   a->next = b->next; /* a->next = a->next->next */
    close(b->soc);
    close(b->psoc);
    efree(&(b->name));
@@ -345,7 +375,8 @@ attack_atom_remove(atoms, name)
  }
 }
 
-int check_threads_input(atoms, sock, globals)
+int 
+check_threads_input(atoms, sock, globals)
  struct attack_atom ** atoms;
  int sock;
  struct arglist * globals;
@@ -355,8 +386,16 @@ int check_threads_input(atoms, sock, globals)
  char buffer[4096];
  int ret = 0;
  int max = -1;
- struct attack_atom * atom = *atoms;
+ struct attack_atom * atom;
  struct arglist * preferences = arg_get_value(globals, "preferences");
+ 
+ 
+ if(!atoms)
+  atom = NULL;
+ else
+   atom = *atoms;
+ 
+ 
  FD_ZERO(&rd);
  FD_ZERO(&wr);
  while(atom)
@@ -375,11 +414,12 @@ int check_threads_input(atoms, sock, globals)
  
  bzero(&tv, sizeof(tv));
  tv.tv_sec = 5;
+ 
+ 
  if(select(max+1, &rd, &wr, NULL, &tv)>0)
- {
-  
+ { 
    /*
-    * Ensure that the client is still here
+    * Make sure that the client is still here
     */
    if((sock >= 0) && !FD_ISSET(sock, &wr))
    {
@@ -410,7 +450,11 @@ int check_threads_input(atoms, sock, globals)
      }
    }
    
-  atom = *atoms;  
+  if(atoms)
+   atom = *atoms;  
+  else
+   atom = NULL;
+   
   while(atom)
   {
     struct attack_atom * next = atom->next;
@@ -420,8 +464,8 @@ int check_threads_input(atoms, sock, globals)
      {
       int len;
       int n;
-      bzero(buffer, 4096);
-      len = recv_line(atom->soc, buffer, 4095);
+      bzero(buffer, sizeof(buffer));
+      len = recv_line(atom->soc, buffer, sizeof(buffer)-1);
       if(!len)
       {
 #ifdef ENABLE_SAVE_TESTS
@@ -431,19 +475,38 @@ int check_threads_input(atoms, sock, globals)
       }
       else
       { 
+       /*
+        * Forward the results to the client
+	*/
        if(sock >= 0)
        {
        n = 0;
        while(n < len)
        {
         int err = send(sock, buffer+n, len - n , 0);
-        if(err >= 0)n += err;
+	if(err < 0)break;
+	else n += err;
         }
        }
+       
+#ifdef ENABLE_SAVE_KB
+        /*
+	 * Copy the message in the email we'll send to the admin
+	 */
+	detached_copy_data(globals, estrdup(buffer), len);
+#endif
+		       
 #ifdef ENABLE_SAVE_TESTS	
-	if(preferences_save_session(preferences))save_tests_write_data(globals, buffer);
+	if(preferences_save_session(preferences))save_tests_write_data(globals, estrdup(buffer));
 	
-#endif	/* send something to tell the son we read his message */
+#endif	
+
+      /* 
+       * send something to tell the son we read his message
+       * this avoids us to be overwhelmed by messages coming
+       * from each sons and filling our mbufs
+       *
+       */
        send(atom->soc, ".", 1, 0);
        ret++;
       }
@@ -463,7 +526,7 @@ int check_threads_input(atoms, sock, globals)
   }
  } 
  else 
-  usleep(100);
+  usleep(1000);
  return ret;
 }
 
@@ -474,10 +537,10 @@ int check_client_input(globals, soc, atoms)
  struct attack_atom ** atoms;
 { 
  struct nessusd_threads ** threads = arg_get_value(globals, "threads");
- char buf[4096];
+ char buf[16384];
  char * t, * t2;
- bzero(buf, 4096);
- auth_gets(globals, buf, 4095);
+ bzero(buf, sizeof(buf));
+ auth_gets(globals, buf, sizeof(buf) - 1);
 #ifdef ENABLE_CIPHER_LAYER
   if(!strlen(buf))return(-1);
 #endif
@@ -584,7 +647,7 @@ create_pid_file()
  f = fopen(fname, "w");
  if(!f)
  {
-  perror("open ");
+  perror("create_pid_file() : open ");
   return;
  }
  fprintf(f, "%d\n", getpid());
@@ -597,5 +660,53 @@ delete_pid_file()
  char * fname = NESSUSD_STATEDIR"/nessusd.pid";
  unlink(fname);
 }
+
+
+char*
+temp_file_name(id)
+ int id;
+{
+ char* ret = emalloc(strlen(NESSUSD_STATEDIR)+strlen("tmp") + 20);
+ sprintf(ret, "%s/tmp.%d", NESSUSD_STATEDIR, id);
+ return ret;
+}
  
  
+
+/*---------------------------------------------------------------------
+
+	Determines if a process is alive - as reliably as we can
+
+-----------------------------------------------------------------------*/
+
+int process_alive(pid)
+ pid_t pid;
+{
+ char procname[255];
+ DIR * dir;
+ int ret = 0;
+ 
+ /*
+  * First method : attempt to open /proc/<pid>
+  */
+ sprintf(procname, "/proc/%d", getpid());
+ dir = opendir(procname);
+ if(dir)
+ {
+ closedir(dir);
+ sprintf(procname, "/proc/%d", pid);
+ dir = opendir(procname);
+ if(dir){
+ 	closedir(dir);
+	return 1;
+	}
+ else return 0;
+ }
+ 
+  /*
+   * Second method, we attempt to use kill. But first, we
+   * wait() for the process, just in case it's a zombie.
+   */
+  waitpid(pid, NULL, WNOHANG);
+  return kill(pid, 0) == 0;
+}
